@@ -40,7 +40,7 @@ sys_query_module(tcp)
 struct tcb *tcp;
 {
 
-	if (entering(tcp)) {
+	if (exiting(tcp)) {
 		printstr(tcp, tcp->u_arg[0], -1);
 		tprintf(", ");
 		printxval(which, tcp->u_arg[1], "L_???");
@@ -51,5 +51,26 @@ struct tcb *tcp;
 	return 0;
 }
 
+int
+sys_create_module(tcp)
+struct tcb *tcp;
+{
+	if (entering(tcp)) {
+		printpath(tcp, tcp->u_arg[0]);
+		tprintf(", %lu", tcp->u_arg[1]);
+	}
+	return RVAL_HEX;
+}
+
+int
+sys_init_module(tcp)
+struct tcb *tcp;
+{
+	if (entering(tcp)) {
+		printpath(tcp, tcp->u_arg[0]);
+		tprintf(", %#lx", tcp->u_arg[1]);
+	}
+	return 0;
+}
 #endif /* LINUX */
 
