@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: file.c,v 1.16 1999/07/09 00:32:54 wichert Exp $
+ *	$Id: file.c,v 1.17 1999/11/18 17:09:47 wichert Exp $
  */
 
 #include "defs.h"
@@ -1214,6 +1214,20 @@ struct tcb *tcp;
 	return 0;
 }
 
+#ifdef ALPHA
+int
+sys_osf_utimes(tcp)
+struct tcb *tcp;
+{
+    if (entering(tcp)) {
+	printpath(tcp, tcp->u_arg[0]);
+	tprintf(", ");
+	printtv32(tcp, tcp->u_arg[1]);
+    }
+    return 0;
+}
+#endif
+
 int
 sys_utimes(tcp)
 struct tcb *tcp;
