@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: io.c,v 1.2 1999/05/09 00:29:58 wichert Exp $
+ *	$Id: io.c,v 1.3 1999/08/29 23:15:07 wichert Exp $
  */
 
 #include "defs.h"
@@ -152,9 +152,14 @@ struct tcb *tcp;
 			tprintf("%#lx", tcp->u_arg[1]);
 		else
 			printstr(tcp, tcp->u_arg[1], tcp->u_rval);
+#if UNIXWARE
+		/* off_t is signed int */
+		tprintf(", %lu, %ld", tcp->u_arg[2], tcp->u_arg[3]);
+#else
 		tprintf(", %lu, %llu", tcp->u_arg[2],
 				(((unsigned long long) tcp->u_arg[4]) << 32
 				 | tcp->u_arg[3]));
+#endif
 	}
 	return 0;
 }
@@ -166,9 +171,14 @@ struct tcb *tcp;
 	if (entering(tcp)) {
 		tprintf("%ld, ", tcp->u_arg[0]);
 		printstr(tcp, tcp->u_arg[1], tcp->u_arg[2]);
+#if UNIXWARE
+		/* off_t is signed int */
+		tprintf(", %lu, %ld", tcp->u_arg[2], tcp->u_arg[3]);
+#else
 		tprintf(", %lu, %llu", tcp->u_arg[2],
 				(((unsigned long long) tcp->u_arg[4]) << 32
 				 | tcp->u_arg[3]));
+#endif
 	}
 	return 0;
 }
