@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscall.h,v 1.3 1999/06/03 14:21:07 wichert Exp $
+ *	$Id: syscall.h,v 1.6 1999/11/18 17:26:46 wichert Exp $
  */
 
 #include "dummy.h"
@@ -95,7 +95,20 @@ int sys_shutdown(), sys_setsockopt(), sys_getsockopt();
 int sys_query_module();
 int sys_poll();
 
-#ifndef ALPHA
+/* architecture-specific calls */
+#ifdef ALPHA
+int sys_osf_select();
+int sys_osf_gettimeofday();
+int sys_osf_settimeofday();
+int sys_osf_getitimer();
+int sys_osf_setitimer();
+int sys_osf_getrusage();
+int sys_osf_wait4();
+int sys_osf_utimes();
+#endif
+
+
+#if !defined(ALPHA) && !defined(MIPS)
 #ifdef POWERPC
 #  define SYS_socket_subcall	256
 #else
@@ -116,8 +129,10 @@ int sys_poll();
 #define SYS_shutdown		(SYS_socket_subcall + 13)
 #define SYS_setsockopt		(SYS_socket_subcall + 14)
 #define SYS_getsockopt		(SYS_socket_subcall + 15)
+#define SYS_sendmsg		(SYS_socket_subcall + 16)
+#define SYS_recvmsg		(SYS_socket_subcall + 17)
 
-#define SYS_socket_nsubcalls	16
+#define SYS_socket_nsubcalls	18
 #endif /* !ALPHA */
 
 /* sys_ipc subcalls */
@@ -126,7 +141,7 @@ int sys_semget(), sys_semctl();
 int sys_msgsnd(), sys_msgrcv(), sys_msgget(), sys_msgctl();
 int sys_shmat(), sys_shmdt(), sys_shmget(), sys_shmctl();
 
-#ifndef ALPHA
+#if !defined(ALPHA) && !defined(MIPS)
 #ifdef POWERPC
 #  define SYS_ipc_subcall		((SYS_socket_subcall)+(SYS_socket_nsubcalls))
 #else
