@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: mem.c,v 1.8 1999/06/22 15:28:30 wichert Exp $
+ *	$Id: mem.c,v 1.10 1999/11/18 17:09:47 wichert Exp $
  */
 
 #include "defs.h"
@@ -124,6 +124,9 @@ static struct xlat mmap_flags[] = {
 #ifdef MAP_EXECUTABLE
 	{ MAP_EXECUTABLE,"MAP_EXECUTABLE"},
 #endif
+#ifdef MAP_INHERIT
+	{ MAP_INHERIT,"MAP_INHERIT"	},
+#endif
 #ifdef MAP_FILE
 	{ MAP_FILE,"MAP_FILE"},
 #endif
@@ -138,7 +141,7 @@ sys_mmap(tcp)
 struct tcb *tcp;
 {
 #ifdef LINUX
-#  if defined(ALPHA) || defined(sparc) || defined(POWERPC)
+#  if defined(ALPHA) || defined(sparc) || defined(POWERPC) || defined(MIPS)
 	long *u_arg = tcp->u_arg;
 #  else /* !ALPHA */
 	long u_arg[6];
@@ -148,7 +151,7 @@ struct tcb *tcp;
 #endif /* !LINUX */
 
 	if (entering(tcp)) {
-#if defined(LINUX) && !defined(ALPHA) && !defined(sparc) && !defined(POWERPC)
+#if defined(LINUX) && !defined(ALPHA) && !defined(sparc) && !defined(POWERPC) && !defined(MIPS)
 		if (umoven(tcp, tcp->u_arg[0], sizeof u_arg,
 				(char *) u_arg) == -1)
 			return 0;
