@@ -24,12 +24,13 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: proc.c,v 1.2 1999/03/15 19:49:42 wichert Exp $
+ *	$Id: proc.c,v 1.3 1999/08/29 23:15:07 wichert Exp $
  */
 
 #include "defs.h"
 
 #ifdef SVR4
+#ifndef SVR4_MP
 
 static struct xlat proc_status_flags[] = {
 	{ PR_STOPPED,	"PR_STOPPED"	},
@@ -182,5 +183,6 @@ int code, arg;
 	}
 }
 
+#endif /* SVR4_MP */
 #endif /* SVR4 */
 
