@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: process.c,v 1.9 1999/06/11 13:18:40 wichert Exp $
+ *	$Id: process.c,v 1.13 1999/11/18 17:09:47 wichert Exp $
  */
 
 #include "defs.h"
@@ -44,16 +44,22 @@
 #include <machine/reg.h>
 #endif /* SUNOS4 */
 
-#if __GLIBC__ == 2 && __GLIBC_MINOR__ >= 1 && (defined(I386) || defined(M68K))
+#if HAVE_LINUX_PTRACE_H
+#undef PTRACE_SYSCALL
+#include <linux/ptrace.h>
+#endif 
+
+#ifdef HAVE_SYS_REG_H
 # include <sys/reg.h>
+#ifndef PTRACE_PEEKUSR
 # define PTRACE_PEEKUSR PTRACE_PEEKUSER
+#endif
+#ifndef PTRACE_POKEUSR
 # define PTRACE_POKEUSR PTRACE_POKEUSER
 #endif
+#endif
 
 #ifdef LINUX
-#ifndef __GLIBC__
-#include <linux/ptrace.h>
-#endif
 #include <asm/posix_types.h>
 #undef GETGROUPS_T
 #define GETGROUPS_T __kernel_gid_t
@@ -123,6 +129,12 @@ static struct xlat prctl_options[] = {
 #endif
 #ifdef PR_PTHREADEXIT
 	{ PR_PTHREADEXIT,	"PR_PTHREADEXIT"	},
+#endif
+#ifdef PR_SET_PDEATHSIG
+	{ PR_SET_PDEATHSIG,	"PR_SET_PDEATHSIG"	},
+#endif
+#ifdef PR_GET_PDEATHSIG
+	{ PR_GET_PDEATHSIG,	"PR_GET_PDEATHSIG"	},
 #endif
 	{ 0,			NULL			},
 };
@@ -139,12 +151,27 @@ struct tcb *tcp;
 #ifdef PR_GETNSHARE
 		case PR_GETNSHARE:
 			break;
+#endif
+#ifdef PR_SET_DEATHSIG
+		case PR_GET_PDEATHSIG:
+			break;
 #endif
 		default:
 			for (i = 1; i < tcp->u_nargs; i++)
 				tprintf(", %#lx", tcp->u_arg[i]);
 			break;
 		}
+	} else {
+		switch (tcp->u_arg[0]) {
+#ifdef PR_GET_PDEATHSIG
+		case PR_GET_PDEATHSIG:
+			for (i=1; i<tcp->u_nargs; i++)
+				tprintf(", %@lx", tcp->u_arg[i]);
+			break;
+#endif
+		default:
+			break;
+		}
 	}
 	return 0;
 }
@@ -932,9 +959,10 @@ int status;
 }
 
 static int
-printwaitn(tcp, n)
+printwaitn(tcp, n, bitness)
 struct tcb *tcp;
 int n;
+int bitness;
 {
 	int status;
 	int exited = 0;
@@ -961,8 +989,14 @@ int n;
 			if (!tcp->u_arg[3])
 				tprintf("NULL");
 #ifdef LINUX
-			else if (tcp->u_rval > 0)
-				printrusage(tcp, tcp->u_arg[3]);
+			else if (tcp->u_rval > 0) {
+#ifdef LINUX_64BIT
+				if (bitness)
+					printrusage32(tcp, tcp->u_arg[3]);
+				else
+#endif
+					printrusage(tcp, tcp->u_arg[3]);
+			}
 #endif /* LINUX */
 #ifdef SUNOS4
 			else if (tcp->u_rval > 0 && exited)
@@ -1010,16 +1044,25 @@ int
 sys_waitpid(tcp)
 struct tcb *tcp;
 {
-	return printwaitn(tcp, 3);
+	return printwaitn(tcp, 3, 0);
 }
 
 int
 sys_wait4(tcp)
 struct tcb *tcp;
 {
-	return printwaitn(tcp, 4);
+	return printwaitn(tcp, 4, 0);
 }
 
+#ifdef ALPHA
+int
+sys_osf_wait4(tcp)
+struct tcb *tcp;
+{
+	return printwaitn(tcp, 4, 1);
+}
+#endif
+
 #ifdef SVR4
 
 static struct xlat waitid_types[] = {
@@ -1530,7 +1573,9 @@ struct xlat struct_user_offsets[] = {
 	{ 4*PT_PC,		"4*PT_PC"				},
 #endif /* M68K */
 #endif /* !I386 */
+#ifndef MIPS
 	{ uoff(u_fpvalid),	"offsetof(struct user, u_fpvalid)"	},
+#endif
 #ifdef I386
 	{ uoff(i387),		"offsetof(struct user, i387)"		},
 #else /* !I386 */
@@ -1544,9 +1589,11 @@ struct xlat struct_user_offsets[] = {
 	{ uoff(start_code),	"offsetof(struct user, start_code)"	},
 	{ uoff(start_stack),	"offsetof(struct user, start_stack)"	},
 	{ uoff(signal),		"offsetof(struct user, signal)"		},
+#ifndef MIPS
 	{ uoff(reserved),	"offsetof(struct user, reserved)"	},
+#endif
 	{ uoff(u_ar0),		"offsetof(struct user, u_ar0)"		},
-#ifndef ARM
+#if !defined(ARM) && !defined(MIPS)
 	{ uoff(u_fpstate),	"offsetof(struct user, u_fpstate)"	},
 #endif
 	{ uoff(magic),		"offsetof(struct user, magic)"		},
