@@ -26,36 +26,42 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: signal.c,v 1.10 1999/06/03 14:21:07 wichert Exp $
+ *	$Id: signal.c,v 1.15 1999/10/31 21:15:38 wichert Exp $
  */
 
 #include "defs.h"
 
-/* ugly hack to make header file do what I want - davidw  */
-#ifdef __arm__
-#undef __USE_POSIX199309
-#endif
-
 #include <signal.h>
 #include <sys/user.h>
 #include <fcntl.h>
-#if __GLIBC__ == 2 && __GLIBC_MINOR__ >= 1 && (defined(I386) || defined(M68K))
-# include <sys/reg.h>
-#endif
 
 #ifdef SVR4
 #include <sys/ucontext.h>
 #endif /* SVR4 */
 
-#ifdef LINUX
-#ifndef __GLIBC__
+#if HAVE_LINUX_PTRACE_H
+#undef PTRACE_SYSCALL
 #include <linux/ptrace.h>
+#endif 
+
+#ifdef HAVE_SYS_REG_H
+# include <sys/reg.h>
+#ifndef PTRACE_PEEKUSR
+# define PTRACE_PEEKUSR PTRACE_PEEKUSER
 #endif
+#ifndef PTRACE_POKEUSR
+# define PTRACE_POKEUSR PTRACE_POKEUSER
+#endif
+#endif
+
+#ifdef LINUX
+
 #ifdef HAVE_ASM_SIGCONTEXT_H
 #include <asm/sigcontext.h>
 #ifdef SPARC
+#include <asm/reg.h>
 typedef struct {
-	struct pt_regs		si_regs;
+	struct regs		si_regs;
 	int			si_mask;
 } m_siginfo_t;
 #endif
@@ -227,6 +233,7 @@ int sig;
 	}
 }
 
+#ifndef UNIXWARE
 static void
 long_to_sigset(l, s)
 long l;
@@ -235,6 +242,7 @@ sigset_t *s;
 	sigemptyset(s);
 	*(long *)s = l;
 }
+#endif
 
 static int
 copy_sigset_len(tcp, addr, s, len)
@@ -778,18 +786,16 @@ struct tcb *tcp;
 #else
 #ifdef SPARC
 	long i1;
-	struct pt_regs regs;
+	struct regs regs;
 	m_siginfo_t si;
 
 	if(ptrace(PTRACE_GETREGS, tcp->pid, (char *)&regs, 0) < 0) {
 	    perror("sigreturn: PTRACE_GETREGS ");
 	    return 0;
 	}
-	memmove (&regs.u_regs [1], &regs.u_regs [0],
-			sizeof (regs.u_regs) - sizeof (regs.u_regs [0]));
 	if(entering(tcp)) {
 		tcp->u_arg[0] = 0;
-		i1 = regs.u_regs[UREG_I1];
+		i1 = regs.r_o1;
 		if(umove(tcp, i1, &si) < 0) {
 			perror("sigreturn: umove ");
 			return 0;
@@ -806,6 +812,28 @@ struct tcb *tcp;
 		return RVAL_NONE | RVAL_STR;
 	}
 	return 0;
+#else  
+#ifdef MIPS
+	long sp;
+	struct sigcontext sc;
+
+	if(entering(tcp)) {
+	  	tcp->u_arg[0] = 0;
+		if (upeek(tcp->pid, REG_SP, &sp) < 0)
+		  	return 0;
+		if (umove(tcp, sp, &sc) < 0)
+		  	return 0;
+		tcp->u_arg[0] = 1;
+		tcp->u_arg[1] = sc.sc_sigset;
+	} else {
+	  	tcp->u_rval = tcp->u_error = 0;
+		if(tcp->u_arg[0] == 0)
+		  	return 0;
+		tcp->auxstr = sprintsigmask("mask now ", tcp->u_arg[1]);
+		return RVAL_NONE | RVAL_STR;
+	}
+	return 0;
+#endif /* MIPS */
 #endif /* SPARC */
 #endif /* ALPHA */
 #endif /* !M68K */
