@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscall.c,v 1.9 1999/06/24 13:55:29 wichert Exp $
+ *	$Id: syscall.c,v 1.13 1999/10/31 21:15:38 wichert Exp $
  */
 
 #include "defs.h"
@@ -38,12 +38,20 @@
 #include <sys/syscall.h>
 #include <sys/param.h>
 
-#if __GLIBC__ == 2 && ((defined(I386) && __GLIBC_MINOR__ >= 0) || (defined(M68K) && __GLIBC_MINOR__ >= 1))
-# include <sys/reg.h>
-#else
-# if defined LINUX
-#  include <linux/ptrace.h>
-# endif /* LINUX */
+#if HAVE_ASM_REG_H
+#include <asm/reg.h>
+#endif
+
+#if HAVE_LINUX_PTRACE_H
+#undef PTRACE_SYSCALL
+#include <linux/ptrace.h>
+#endif 
+
+#ifdef HAVE_SYS_REG_H
+#include <sys/reg.h>
+#ifndef PTRACE_PEEKUSR
+# define PTRACE_PEEKUSR PTRACE_PEEKUSER
+#endif
 #endif
 
 #ifndef SYS_ERRLIST_DECLARED
@@ -398,7 +406,7 @@ struct tcb *tcp;
 
 enum subcall_style { shift_style, deref_style, mask_style, door_style };
 
-#if !(defined(LINUX) && defined(ALPHA))
+#if !(defined(LINUX) && ( defined(ALPHA) || defined(MIPS) ))
 
 const int socket_map [] = {
 	       /* SYS_SOCKET      */ 97,
@@ -577,8 +585,10 @@ struct tcb *tcp;
 #elif defined (ALPHA)
 	long r0;
 	long a3;
+#elif defined(MIPS)
+	long r2,a3;
 #elif defined (SPARC)
-	struct pt_regs regs;
+	struct regs regs;
 	unsigned long trap;
 #endif 
 #endif /* LINUX */
@@ -614,6 +624,25 @@ struct tcb *tcp;
 #elif defined (M68K)
 	if (upeek(pid, 4*PT_ORIG_D0, &scno) < 0)
 		return -1;
+#elif defined (MIPS)
+	if (upeek(pid, REG_A3, &a3) < 0)
+	  	return -1;
+
+	if(!(tcp->flags & TCB_INSYSCALL)) {
+	  	if (upeek(pid, REG_V0, &scno) < 0)
+		  	return -1;
+
+		if (scno < 0 || scno > nsyscalls) {
+			if(a3 == 0 || a3 == -1) {
+				if(debug)
+					fprintf (stderr, "stray syscall exit: v0 = %ld\n", scno);
+				return 0;
+			}
+		}
+	} else {
+	  	if (upeek(pid, REG_V0, &r2) < 0)
+	    		return -1;
+	}
 #elif defined (ALPHA)
 	if (upeek(pid, REG_A3, &a3) < 0)
 		return -1;
@@ -649,14 +678,11 @@ struct tcb *tcp;
 	if (ptrace(PTRACE_GETREGS,pid,(char *)&regs,0) < 0)
 		return -1;
 
-	memmove (&regs.u_regs [1], &regs.u_regs [0],
-		 sizeof (regs.u_regs) - sizeof (regs.u_regs [0]));
-
         /* If we are entering, then disassemble the syscall trap. */
 	if (!(tcp->flags & TCB_INSYSCALL)) {
 		/* Retrieve the syscall trap instruction. */
 		errno = 0;
-		trap = ptrace(PTRACE_PEEKTEXT,pid,(char *)regs.pc,0);
+		trap = ptrace(PTRACE_PEEKTEXT,pid,(char *)regs.r_pc,0);
 		if (errno)
 			return -1;
 
@@ -692,7 +718,7 @@ struct tcb *tcp;
 				tcp->flags &= ~TCB_WAITEXECVE;
 				return 0;
 			}
-			fprintf(stderr,"syscall: unknown syscall trap %08x %08x\n", trap, regs.pc);
+			fprintf(stderr,"syscall: unknown syscall trap %08x %08x\n", trap, regs.r_pc);
 			return -1;
 		}
 
@@ -700,10 +726,10 @@ struct tcb *tcp;
 		if (trap == 0x91d02027)
 			scno = 156;
 		else
-			scno = regs.u_regs[UREG_G1];
+			scno = regs.r_g1;
 		if (scno == 0) {
-			scno = regs.u_regs[UREG_I0];
-			memmove (&regs.u_regs[UREG_I0], &regs.u_regs[UREG_I1], 7*sizeof(regs.u_regs[0]));
+			scno = regs.r_o0;
+			memmove (&regs.r_o0, &regs.r_o1, 7*sizeof(regs.r_o0));
 		}
 	}
 #endif 
@@ -716,10 +742,10 @@ struct tcb *tcp;
 #ifdef HAVE_PR_SYSCALL
 	scno = tcp->status.pr_syscall;
 #else /* !HAVE_PR_SYSCALL */
-	scno = tcp->status.pr_what;
+	scno = tcp->status.PR_WHAT;
 #endif /* !HAVE_PR_SYSCALL */
 	if (!(tcp->flags & TCB_INSYSCALL)) {
-		if (tcp->status.pr_why != PR_SYSENTRY) {
+		if (tcp->status.PR_WHY != PR_SYSENTRY) {
 			if (
 			    scno == SYS_fork
 #ifdef SYS_vfork
@@ -727,9 +753,9 @@ struct tcb *tcp;
 #endif /* SYS_vfork */
 			    ) {
 				/* We are returning in the child, fake it. */
-				tcp->status.pr_why = PR_SYSENTRY;
+				tcp->status.PR_WHY = PR_SYSENTRY;
 				trace_syscall(tcp);
-				tcp->status.pr_why = PR_SYSEXIT;
+				tcp->status.PR_WHY = PR_SYSEXIT;
 			}
 			else {
 				fprintf(stderr, "syscall: missing entry\n");
@@ -738,7 +764,7 @@ struct tcb *tcp;
 		}
 	}
 	else {
-		if (tcp->status.pr_why != PR_SYSEXIT) {
+		if (tcp->status.PR_WHY != PR_SYSEXIT) {
 			fprintf(stderr, "syscall: missing exit\n");
 			tcp->flags &= ~TCB_INSYSCALL;
 		}
@@ -816,6 +842,15 @@ struct tcb *tcp;
 			u_error = 0;
 		}
 #else /* !I386 */
+#ifdef MIPS
+		if (a3) {
+		  	tcp->u_rval = -1;
+			u_error = r2;
+		} else {
+		  	tcp->u_rval = r2;
+			u_error = 0;
+		}
+#else
 #ifdef POWERPC
 		if (result && (unsigned) -result < nerrnos) {
 			tcp->u_rval = -1;
@@ -857,12 +892,12 @@ struct tcb *tcp;
 		}
 #else /* !ALPHA */
 #ifdef SPARC
-		if (regs.psr & PSR_C) {
+		if (regs.r_psr & PSR_C) {
 			tcp->u_rval = -1;
-			u_error = regs.u_regs[UREG_I0];
+			u_error = regs.r_o0;
 		}
 		else {
-			tcp->u_rval = regs.u_regs[UREG_I0];
+			tcp->u_rval = regs.r_o0;
 			u_error = 0;
 		}
 #endif /* SPARC */
@@ -870,6 +905,7 @@ struct tcb *tcp;
 #endif /* ARM */
 #endif /* M68K */
 #endif /* POWERPC */
+#endif /* MIPS */
 #endif /* I386 */
 #endif /* LINUX */
 #ifdef SUNOS4
@@ -896,12 +932,12 @@ struct tcb *tcp;
 #endif /* SPARC */
 #ifdef I386
 		/* Wanna know how to kill an hour single-stepping? */
-		if (tcp->status.pr_reg[EFL] & 0x1) {
+		if (tcp->status.PR_REG[EFL] & 0x1) {
 			tcp->u_rval = -1;
-			u_error = tcp->status.pr_reg[EAX];
+			u_error = tcp->status.PR_REG[EAX];
 		}
 		else {
-			tcp->u_rval = tcp->status.pr_reg[EAX];
+			tcp->u_rval = tcp->status.PR_REG[EAX];
 			u_error = 0;
 		}
 #endif /* I386 */
@@ -1062,6 +1098,28 @@ struct tcb *tcp;
 				return -1;
 		}
 	}
+#elif defined (MIPS)
+	{
+	  	long sp;
+	  	int i, nargs;
+
+		nargs = tcp->u_nargs = sysent[tcp->scno].nargs;
+		if(nargs > 4) {
+		  	if(upeek(pid, REG_SP, &sp) < 0)
+			  	return -1;
+			for(i = 0; i < 4; i++) {
+			  	if (upeek(pid, REG_A0 + i, &tcp->u_arg[i])<0)
+				  	return -1;
+			}
+			umoven(tcp, sp+16, (nargs-4) * sizeof(tcp->u_arg[0]),
+			       (char *)(tcp->u_arg + 4));
+		} else {
+		  	for(i = 0; i < nargs; i++) {
+			  	if (upeek(pid, REG_A0 + i, &tcp->u_arg[i]) < 0)
+				  	return -1;
+			}
+		}
+	}
 #elif defined (POWERPC)
 	{
 		int i;
@@ -1073,12 +1131,11 @@ struct tcb *tcp;
 	}
 #elif defined (SPARC)
 	{
-		int i, offset;
+		int i;
 	         
-	        offset = UREG_I0;
 		tcp->u_nargs = sysent[tcp->scno].nargs;
 		for (i = 0; i < tcp->u_nargs; i++)
-			tcp->u_arg[i] = regs.u_regs[offset + i];
+			tcp->u_arg[i] = *((&regs.r_o0) + i);
 	}
 #else 
 	{
@@ -1140,8 +1197,12 @@ struct tcb *tcp;
 	if (sysent[tcp->scno].nargs != -1)
 		tcp->u_nargs = sysent[tcp->scno].nargs;
 	else
+#if UNIXWARE >= 2
+		tcp->u_nargs = tcp->status.pr_lwp.pr_nsysarg;
+#else
 		tcp->u_nargs = 5;
-	umoven(tcp, tcp->status.pr_reg[UESP] + 4,
+#endif
+	umoven(tcp, tcp->status.PR_REG[UESP] + 4,
 		tcp->u_nargs*sizeof(tcp->u_arg[0]), (char *) tcp->u_arg);
 #endif /* I386 */
 #endif /* !HAVE_PR_SYSCALL */
@@ -1153,7 +1214,7 @@ struct tcb *tcp;
 	switch (tcp->scno) {
 #endif
 #ifdef LINUX
-#if !defined (ALPHA) && !defined(SPARC)
+#if !defined (ALPHA) && !defined(SPARC) && !defined(MIPS)
 	case SYS_socketcall:
 		decode_subcall(tcp, SYS_socket_subcall,
 			SYS_socket_nsubcalls, deref_style);
@@ -1291,10 +1352,10 @@ struct tcb *tcp;
 
 #ifdef LINUX
 #ifdef SPARC
-	struct pt_regs regs;
+	struct regs regs;
 	if (ptrace(PTRACE_GETREGS,tcp->pid,(char *)&regs,0) < 0)
 		return -1;
-	val = regs.u_regs[UREG_I1];
+	val = regs.r_o1;
 #endif /* SPARC */
 #endif /* LINUX */
 
@@ -1305,13 +1366,13 @@ struct tcb *tcp;
 
 #ifdef SVR4
 #ifdef SPARC
-	val = tcp->status.pr_reg[R_O1];
+	val = tcp->status.PR_REG[R_O1];
 #endif /* SPARC */
 #ifdef I386
-	val = tcp->status.pr_reg[EDX];
+	val = tcp->status.PR_REG[EDX];
 #endif /* I386 */
 #ifdef MIPS
-	val = tcp->status.pr_reg[CTX_V1];
+	val = tcp->status.PR_REG[CTX_V1];
 #endif /* MIPS */
 #endif /* SVR4 */
 
