@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: util.c,v 1.7 1999/06/22 15:28:30 wichert Exp $
+ *	$Id: util.c,v 1.11 1999/10/31 21:15:38 wichert Exp $
  */
 
 #include "defs.h"
@@ -39,15 +39,15 @@
 #include <a.out.h>
 #include <link.h>
 #endif /* SUNOS4 */
-#if __GLIBC__ == 2 && __GLIBC_MINOR__ >= 1 && (defined(I386) || defined(M68K))
-# include <sys/reg.h>
+
+#if defined(linux)
+#include <linux/ptrace.h>
+#endif 
+
+#ifdef HAVE_SYS_REG_H
+#include <sys/reg.h>
 # define PTRACE_PEEKUSR PTRACE_PEEKUSER
 #endif
-#ifdef LINUX
-#if !defined(__GLIBC__) || defined(SPARC)
-#include <linux/ptrace.h>
-#endif
-#endif /* LINUX */
 
 #ifdef HAVE_SYS_PTRACE_H
 #include <sys/ptrace.h>
@@ -57,7 +57,11 @@
 #include <sys/utsname.h>
 #endif /* SUNOS4_KERNEL_ARCH_KLUDGE */
 
-#if defined(LINUX) && defined(SPARC) && !defined(__GLIBC__)
+#if defined(LINUX) && defined(SPARC)
+
+#include <asm/reg.h>
+
+#if !defined(__GLIBC__)
 
 #include <linux/unistd.h>
 
@@ -95,6 +99,8 @@ static _hack_syscall5(int,_ptrace,int,__request,int,__pid,int,__addr,int,__data,
 
 #endif
 
+#endif
+
 /* macros */
 #ifndef MAX
 #define MAX(a,b)		(((a) > (b)) ? (a) : (b))
@@ -618,6 +624,10 @@ char *laddr;
 #endif /* SUNOS4 */
 
 #ifdef SVR4
+#ifdef SVR4_MP
+	if (pread(tcp->pfd_as, laddr, len, addr) == -1)
+		return -1;
+#else
 /*
  * We would like to use pread preferentially for speed
  * but even though SGI has it in their library, it no longer works.
@@ -633,6 +643,7 @@ char *laddr;
 	if (read(tcp->pfd, laddr, len) == -1)
 		return -1;
 #endif /* !HAVE_PREAD */
+#endif /* SVR4_MP */
 #endif /* SVR4 */
 
 	return 0;
@@ -857,37 +868,30 @@ struct tcb *tcp;
 #ifdef LINUX
 	long pc;
 
-#ifdef I386
+#if defined(I386)
 	if (upeek(tcp->pid, 4*EIP, &pc) < 0)
 		return -1;
-#else /* !I386 */
-#ifdef ARM
+#elif defined(ARM)
 	if (upeek(tcp->pid, 4*15, &pc) < 0)
 		return -1;
-#else /* !ARM */
-#ifdef POWERPC
+#elif defined(POWERPC)
 	if (upeek(tcp->pid, 4*PT_NIP, &pc) < 0)
 		return -1;
-#else
-#ifdef M68K
+#elif defined(M68k)
 	if (upeek(tcp->pid, 4*PT_PC, &pc) < 0)
 		return -1;
-#else /* !M68K */
-#ifdef ALPHA
+#elif defined(ALPHA)
 	if (upeek(tcp->pid, REG_PC, &pc) < 0)
 		return -1;
-#else /* !ALPHA */
-#ifdef SPARC
-	struct pt_regs regs;
+#elif defined(MIPS)
+ 	if (upeek(tcp->pid, REG_EPC, &pc) < 0)
+ 		return -1;
+#elif defined(SPARC)
+	struct regs regs;
 	if (ptrace(PTRACE_GETREGS,tcp->pid,(char *)&regs,0) < 0)
 		return -1;
-	pc = regs.pc;
-#endif /* SPARC */
-#endif /* ALPHA */
-#endif /* !M68K */
-#endif /* !POWERPC */
-#endif /* !ARM */
-#endif /* !I386 */
+	pc = regs.r_pc;
+#endif
 	return pc;
 #endif /* LINUX */
 
@@ -955,12 +959,12 @@ struct tcb *tcp;
 	tprintf("[%08lx] ", pc);
 #else /* !ALPHA */
 #ifdef SPARC
-	struct pt_regs regs;
+	struct regs regs;
 	if (ptrace(PTRACE_GETREGS,tcp->pid,(char *)&regs,0) < 0) {
 		tprintf("[????????] ");
 		return;
 	}
-	tprintf("[%08lx] ", regs.pc);
+	tprintf("[%08lx] ", regs.r_pc);
 #endif /* SPARC */
 #endif /* ALPHA */
 #endif /* !M68K */
@@ -997,7 +1001,7 @@ struct tcb *tcp;
 #ifdef SPARC
 	/* We simply use the SunOS breakpoint code. */
 
-	struct pt_regs regs;
+	struct regs regs;
 #define LOOPA	0x30800000	/* ba,a	0 */
 
 	if (tcp->flags & TCB_BPTSET) {
@@ -1008,9 +1012,7 @@ struct tcb *tcp;
 		perror("setbpt: ptrace(PTRACE_GETREGS, ...)");
 		return -1;
 	}
-	memmove (&regs.u_regs [1], &regs.u_regs [0],
-		 sizeof (regs.u_regs) - sizeof (regs.u_regs [0]));
-	tcp->baddr = regs.u_regs[UREG_I7] + 8;
+	tcp->baddr = regs.r_o7 + 8;
 	errno = 0;
 	tcp->inst[0] = ptrace(PTRACE_PEEKTEXT, tcp->pid, (char *)tcp->baddr, 0);
 	if(errno) {
@@ -1048,6 +1050,8 @@ struct tcb *tcp;
 #define LOOP 0x0000feeb
 #elif defined(ARM)
 #define LOOP -1  /* almost certainly wrong, jws */
+#elif defined(MIPS)
+#define LOOP 0x1000ffff
 #else
 #error unknown architecture
 #endif
@@ -1066,6 +1070,8 @@ struct tcb *tcp;
 	return -1;
 #elif defined (ARM)
 	return -1;
+#elif defined (MIPS)
+	return -1;		/* FIXME: I do not know what i do - Flo */
 #elif defined (POWERPC)
 	if (upeek(tcp->pid, 4*PT_NIP, &tcp->baddr) < 0)
 		return -1;
